# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [1.0.2 - 1.0.4] - 2024-09-05/2024-09-06

- Fix admin privileges.
- Separate `register_font` admin logic from the main package.
- Improve CLI

## [1.0.1] - 2024-09-05

Fix admin privileges for the `Linux` users.

## [1.0.0] - 2024-09-05

Initial release of Captametropolis! 🎉